#!/usr/bin/env python3
"""
Setup configuration for cloud-seeder package
"""

from setuptools import setup, find_packages
from pathlib import Path

# Read the README file
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="cloud-seeder",
    version="0.1.0",
    author="Chris Watkins",
    author_email="chris@watkinslabs.com",
    description="A tool for generating cloud-init configurations and seed ISOs, works with vmware",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/chris17453/cloud-seeder",
    project_urls={
        "Bug Tracker": "https://github.com/chris17453/cloud-seeder/issues",
        "Documentation": "https://github.com/chris17453/cloud-seeder/wiki",
        "Source Code": "https://github.com/chris17453/cloud-seeder",
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: System Administrators",
        "Topic :: System :: Systems Administration",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: POSIX :: Linux",
        "Environment :: Console",
    ],
    keywords="cloud-init, cloud, automation, infrastructure, devops, seed, iso",
    packages=find_packages(),
    python_requires=">=3.7",
    install_requires=[
        "PyYAML>=5.1",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov>=2.0",
            "black>=21.0",
            "flake8>=3.9",
            "mypy>=0.910",
            "build>=0.7",
            "twine>=3.4",
        ],
    },
    entry_points={
        "console_scripts": [
            "cloud-seeder=cloud_seeder.cli:main",
        ],
    },
    include_package_data=True,
    package_data={
        "cloud_seeder": ["examples/*.yaml"],
    },
)